package androidx.core.graphics.drawable;

import android.content.Context;
import android.content.res.ColorStateList;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.BitmapShader;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.Shader;
import android.graphics.drawable.AdaptiveIconDrawable;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.Icon;
import android.net.Uri;
import android.os.Build;
import android.os.Parcelable;
import android.text.TextUtils;
import android.util.Log;
import androidx.versionedparcelable.CustomVersionedParcelable;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.lang.reflect.InvocationTargetException;
import java.nio.charset.Charset;
/* loaded from: classes.dex */
public class IconCompat extends CustomVersionedParcelable {

    /* renamed from: ˎ  reason: contains not printable characters */
    static final PorterDuff.Mode f2877 = PorterDuff.Mode.SRC_IN;

    /* renamed from: ʼ  reason: contains not printable characters */
    Object f2879;

    /* renamed from: ˋ  reason: contains not printable characters */
    public String f2887;

    /* renamed from: ʻ  reason: contains not printable characters */
    public int f2878 = -1;

    /* renamed from: ʽ  reason: contains not printable characters */
    public byte[] f2880 = null;

    /* renamed from: ʾ  reason: contains not printable characters */
    public Parcelable f2881 = null;

    /* renamed from: ʿ  reason: contains not printable characters */
    public int f2882 = 0;

    /* renamed from: ˆ  reason: contains not printable characters */
    public int f2883 = 0;

    /* renamed from: ˈ  reason: contains not printable characters */
    public ColorStateList f2884 = null;

    /* renamed from: ˉ  reason: contains not printable characters */
    PorterDuff.Mode f2885 = f2877;

    /* renamed from: ˊ  reason: contains not printable characters */
    public String f2886 = null;

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public static class a {
        /* renamed from: ʻ  reason: contains not printable characters */
        static int m2404(Object obj) {
            if (Build.VERSION.SDK_INT >= 28) {
                return c.m2411(obj);
            }
            try {
                return ((Integer) obj.getClass().getMethod("getResId", new Class[0]).invoke(obj, new Object[0])).intValue();
            } catch (IllegalAccessException e6) {
                Log.e("IconCompat", "Unable to get icon resource", e6);
                return 0;
            } catch (NoSuchMethodException e7) {
                Log.e("IconCompat", "Unable to get icon resource", e7);
                return 0;
            } catch (InvocationTargetException e8) {
                Log.e("IconCompat", "Unable to get icon resource", e8);
                return 0;
            }
        }

        /* renamed from: ʼ  reason: contains not printable characters */
        static String m2405(Object obj) {
            if (Build.VERSION.SDK_INT >= 28) {
                return c.m2412(obj);
            }
            try {
                return (String) obj.getClass().getMethod("getResPackage", new Class[0]).invoke(obj, new Object[0]);
            } catch (IllegalAccessException e6) {
                Log.e("IconCompat", "Unable to get icon package", e6);
                return null;
            } catch (NoSuchMethodException e7) {
                Log.e("IconCompat", "Unable to get icon package", e7);
                return null;
            } catch (InvocationTargetException e8) {
                Log.e("IconCompat", "Unable to get icon package", e8);
                return null;
            }
        }

        /* renamed from: ʽ  reason: contains not printable characters */
        static Uri m2406(Object obj) {
            if (Build.VERSION.SDK_INT >= 28) {
                return c.m2414(obj);
            }
            try {
                return (Uri) obj.getClass().getMethod("getUri", new Class[0]).invoke(obj, new Object[0]);
            } catch (IllegalAccessException e6) {
                Log.e("IconCompat", "Unable to get icon uri", e6);
                return null;
            } catch (NoSuchMethodException e7) {
                Log.e("IconCompat", "Unable to get icon uri", e7);
                return null;
            } catch (InvocationTargetException e8) {
                Log.e("IconCompat", "Unable to get icon uri", e8);
                return null;
            }
        }

        /* renamed from: ʾ  reason: contains not printable characters */
        static Drawable m2407(Icon icon, Context context) {
            Drawable loadDrawable;
            loadDrawable = icon.loadDrawable(context);
            return loadDrawable;
        }

        /* renamed from: ʿ  reason: contains not printable characters */
        static Icon m2408(IconCompat iconCompat, Context context) {
            Icon createWithBitmap;
            switch (iconCompat.f2878) {
                case -1:
                    return (Icon) iconCompat.f2879;
                case 0:
                default:
                    throw new IllegalArgumentException("Unknown type");
                case 1:
                    createWithBitmap = Icon.createWithBitmap((Bitmap) iconCompat.f2879);
                    break;
                case 2:
                    createWithBitmap = Icon.createWithResource(iconCompat.m2399(), iconCompat.f2882);
                    break;
                case 3:
                    createWithBitmap = Icon.createWithData((byte[]) iconCompat.f2879, iconCompat.f2882, iconCompat.f2883);
                    break;
                case 4:
                    createWithBitmap = Icon.createWithContentUri((String) iconCompat.f2879);
                    break;
                case 5:
                    if (Build.VERSION.SDK_INT < 26) {
                        createWithBitmap = Icon.createWithBitmap(IconCompat.m2396((Bitmap) iconCompat.f2879, false));
                        break;
                    } else {
                        createWithBitmap = b.m2410((Bitmap) iconCompat.f2879);
                        break;
                    }
                case 6:
                    int i6 = Build.VERSION.SDK_INT;
                    if (i6 >= 30) {
                        createWithBitmap = d.m2415(iconCompat.m2400());
                        break;
                    } else if (context != null) {
                        InputStream m2401 = iconCompat.m2401(context);
                        if (m2401 != null) {
                            if (i6 < 26) {
                                createWithBitmap = Icon.createWithBitmap(IconCompat.m2396(BitmapFactory.decodeStream(m2401), false));
                                break;
                            } else {
                                createWithBitmap = b.m2410(BitmapFactory.decodeStream(m2401));
                                break;
                            }
                        } else {
                            throw new IllegalStateException("Cannot load adaptive icon from uri: " + iconCompat.m2400());
                        }
                    } else {
                        throw new IllegalArgumentException("Context is required to resolve the file uri of the icon: " + iconCompat.m2400());
                    }
            }
            ColorStateList colorStateList = iconCompat.f2884;
            if (colorStateList != null) {
                createWithBitmap.setTintList(colorStateList);
            }
            PorterDuff.Mode mode = iconCompat.f2885;
            if (mode != IconCompat.f2877) {
                createWithBitmap.setTintMode(mode);
            }
            return createWithBitmap;
        }
    }

    /* loaded from: classes.dex */
    static class b {
        /* renamed from: ʻ  reason: contains not printable characters */
        static Drawable m2409(Drawable drawable, Drawable drawable2) {
            return new AdaptiveIconDrawable(drawable, drawable2);
        }

        /* renamed from: ʼ  reason: contains not printable characters */
        static Icon m2410(Bitmap bitmap) {
            Icon createWithAdaptiveBitmap;
            createWithAdaptiveBitmap = Icon.createWithAdaptiveBitmap(bitmap);
            return createWithAdaptiveBitmap;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public static class c {
        /* renamed from: ʻ  reason: contains not printable characters */
        static int m2411(Object obj) {
            int resId;
            resId = ((Icon) obj).getResId();
            return resId;
        }

        /* renamed from: ʼ  reason: contains not printable characters */
        static String m2412(Object obj) {
            String resPackage;
            resPackage = ((Icon) obj).getResPackage();
            return resPackage;
        }

        /* renamed from: ʽ  reason: contains not printable characters */
        static int m2413(Object obj) {
            int type;
            type = ((Icon) obj).getType();
            return type;
        }

        /* renamed from: ʾ  reason: contains not printable characters */
        static Uri m2414(Object obj) {
            Uri uri;
            uri = ((Icon) obj).getUri();
            return uri;
        }
    }

    /* loaded from: classes.dex */
    static class d {
        /* renamed from: ʻ  reason: contains not printable characters */
        static Icon m2415(Uri uri) {
            Icon createWithAdaptiveBitmapContentUri;
            createWithAdaptiveBitmapContentUri = Icon.createWithAdaptiveBitmapContentUri(uri);
            return createWithAdaptiveBitmapContentUri;
        }
    }

    /* renamed from: ʻ  reason: contains not printable characters */
    static Bitmap m2396(Bitmap bitmap, boolean z5) {
        int min = (int) (Math.min(bitmap.getWidth(), bitmap.getHeight()) * 0.6666667f);
        Bitmap createBitmap = Bitmap.createBitmap(min, min, Bitmap.Config.ARGB_8888);
        Canvas canvas = new Canvas(createBitmap);
        Paint paint = new Paint(3);
        float f6 = min;
        float f7 = 0.5f * f6;
        float f8 = 0.9166667f * f7;
        if (z5) {
            float f9 = 0.010416667f * f6;
            paint.setColor(0);
            paint.setShadowLayer(f9, 0.0f, f6 * 0.020833334f, 1023410176);
            canvas.drawCircle(f7, f7, f8, paint);
            paint.setShadowLayer(f9, 0.0f, 0.0f, 503316480);
            canvas.drawCircle(f7, f7, f8, paint);
            paint.clearShadowLayer();
        }
        paint.setColor(-16777216);
        Shader.TileMode tileMode = Shader.TileMode.CLAMP;
        BitmapShader bitmapShader = new BitmapShader(bitmap, tileMode, tileMode);
        Matrix matrix = new Matrix();
        matrix.setTranslate((-(bitmap.getWidth() - min)) / 2.0f, (-(bitmap.getHeight() - min)) / 2.0f);
        bitmapShader.setLocalMatrix(matrix);
        paint.setShader(bitmapShader);
        canvas.drawCircle(f7, f7, f8, paint);
        canvas.setBitmap(null);
        return createBitmap;
    }

    /* renamed from: ˉ  reason: contains not printable characters */
    private static String m2397(int i6) {
        switch (i6) {
            case 1:
                return "BITMAP";
            case 2:
                return "RESOURCE";
            case 3:
                return "DATA";
            case 4:
                return "URI";
            case 5:
                return "BITMAP_MASKABLE";
            case 6:
                return "URI_MASKABLE";
            default:
                return "UNKNOWN";
        }
    }

    public String toString() {
        if (this.f2878 == -1) {
            return String.valueOf(this.f2879);
        }
        StringBuilder sb = new StringBuilder("Icon(typ=");
        sb.append(m2397(this.f2878));
        switch (this.f2878) {
            case 1:
            case 5:
                sb.append(" size=");
                sb.append(((Bitmap) this.f2879).getWidth());
                sb.append("x");
                sb.append(((Bitmap) this.f2879).getHeight());
                break;
            case 2:
                sb.append(" pkg=");
                sb.append(this.f2887);
                sb.append(" id=");
                sb.append(String.format("0x%08x", Integer.valueOf(m2398())));
                break;
            case 3:
                sb.append(" len=");
                sb.append(this.f2882);
                if (this.f2883 != 0) {
                    sb.append(" off=");
                    sb.append(this.f2883);
                    break;
                }
                break;
            case 4:
            case 6:
                sb.append(" uri=");
                sb.append(this.f2879);
                break;
        }
        if (this.f2884 != null) {
            sb.append(" tint=");
            sb.append(this.f2884);
        }
        if (this.f2885 != f2877) {
            sb.append(" mode=");
            sb.append(this.f2885);
        }
        sb.append(")");
        return sb.toString();
    }

    /* renamed from: ʼ  reason: contains not printable characters */
    public int m2398() {
        int i6 = this.f2878;
        if (i6 == -1 && Build.VERSION.SDK_INT >= 23) {
            return a.m2404(this.f2879);
        }
        if (i6 == 2) {
            return this.f2882;
        }
        throw new IllegalStateException("called getResId() on " + this);
    }

    /* renamed from: ʽ  reason: contains not printable characters */
    public String m2399() {
        int i6 = this.f2878;
        if (i6 == -1 && Build.VERSION.SDK_INT >= 23) {
            return a.m2405(this.f2879);
        }
        if (i6 == 2) {
            String str = this.f2887;
            if (str != null && !TextUtils.isEmpty(str)) {
                return this.f2887;
            }
            return ((String) this.f2879).split(":", -1)[0];
        }
        throw new IllegalStateException("called getResPackage() on " + this);
    }

    /* renamed from: ʾ  reason: contains not printable characters */
    public Uri m2400() {
        int i6 = this.f2878;
        if (i6 == -1 && Build.VERSION.SDK_INT >= 23) {
            return a.m2406(this.f2879);
        }
        if (i6 != 4 && i6 != 6) {
            throw new IllegalStateException("called getUri() on " + this);
        }
        return Uri.parse((String) this.f2879);
    }

    /* renamed from: ʿ  reason: contains not printable characters */
    public InputStream m2401(Context context) {
        Uri m2400 = m2400();
        String scheme = m2400.getScheme();
        if (!"content".equals(scheme) && !"file".equals(scheme)) {
            try {
                return new FileInputStream(new File((String) this.f2879));
            } catch (FileNotFoundException e6) {
                Log.w("IconCompat", "Unable to load image from path: " + m2400, e6);
                return null;
            }
        }
        try {
            return context.getContentResolver().openInputStream(m2400);
        } catch (Exception e7) {
            Log.w("IconCompat", "Unable to load image from URI: " + m2400, e7);
            return null;
        }
    }

    /* renamed from: ˆ  reason: contains not printable characters */
    public void m2402() {
        this.f2885 = PorterDuff.Mode.valueOf(this.f2886);
        switch (this.f2878) {
            case -1:
                Parcelable parcelable = this.f2881;
                if (parcelable != null) {
                    this.f2879 = parcelable;
                    return;
                }
                throw new IllegalArgumentException("Invalid icon");
            case 0:
            default:
                return;
            case 1:
            case 5:
                Parcelable parcelable2 = this.f2881;
                if (parcelable2 != null) {
                    this.f2879 = parcelable2;
                    return;
                }
                byte[] bArr = this.f2880;
                this.f2879 = bArr;
                this.f2878 = 3;
                this.f2882 = 0;
                this.f2883 = bArr.length;
                return;
            case 2:
            case 4:
            case 6:
                String str = new String(this.f2880, Charset.forName("UTF-16"));
                this.f2879 = str;
                if (this.f2878 == 2 && this.f2887 == null) {
                    this.f2887 = str.split(":", -1)[0];
                    return;
                }
                return;
            case 3:
                this.f2879 = this.f2880;
                return;
        }
    }

    /* renamed from: ˈ  reason: contains not printable characters */
    public void m2403(boolean z5) {
        this.f2886 = this.f2885.name();
        switch (this.f2878) {
            case -1:
                if (!z5) {
                    this.f2881 = (Parcelable) this.f2879;
                    return;
                }
                throw new IllegalArgumentException("Can't serialize Icon created with IconCompat#createFromIcon");
            case 0:
            default:
                return;
            case 1:
            case 5:
                if (z5) {
                    ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
                    ((Bitmap) this.f2879).compress(Bitmap.CompressFormat.PNG, 90, byteArrayOutputStream);
                    this.f2880 = byteArrayOutputStream.toByteArray();
                    return;
                }
                this.f2881 = (Parcelable) this.f2879;
                return;
            case 2:
                this.f2880 = ((String) this.f2879).getBytes(Charset.forName("UTF-16"));
                return;
            case 3:
                this.f2880 = (byte[]) this.f2879;
                return;
            case 4:
            case 6:
                this.f2880 = this.f2879.toString().getBytes(Charset.forName("UTF-16"));
                return;
        }
    }
}
