package com.google.gson.stream;

import com.google.gson.internal.JsonReaderInternalAccess;
import com.google.gson.internal.bind.JsonTreeReader;
import java.io.Closeable;
import java.io.EOFException;
import java.io.IOException;
import java.io.Reader;
import java.util.Arrays;
/* loaded from: classes.dex */
public class JsonReader implements Closeable {
    private static final long MIN_INCOMPLETE_INTEGER = -922337203685477580L;
    private static final int NUMBER_CHAR_DECIMAL = 3;
    private static final int NUMBER_CHAR_DIGIT = 2;
    private static final int NUMBER_CHAR_EXP_DIGIT = 7;
    private static final int NUMBER_CHAR_EXP_E = 5;
    private static final int NUMBER_CHAR_EXP_SIGN = 6;
    private static final int NUMBER_CHAR_FRACTION_DIGIT = 4;
    private static final int NUMBER_CHAR_NONE = 0;
    private static final int NUMBER_CHAR_SIGN = 1;
    private static final int PEEKED_BEGIN_ARRAY = 3;
    private static final int PEEKED_BEGIN_OBJECT = 1;
    private static final int PEEKED_BUFFERED = 11;
    private static final int PEEKED_DOUBLE_QUOTED = 9;
    private static final int PEEKED_DOUBLE_QUOTED_NAME = 13;
    private static final int PEEKED_END_ARRAY = 4;
    private static final int PEEKED_END_OBJECT = 2;
    private static final int PEEKED_EOF = 17;
    private static final int PEEKED_FALSE = 6;
    private static final int PEEKED_LONG = 15;
    private static final int PEEKED_NONE = 0;
    private static final int PEEKED_NULL = 7;
    private static final int PEEKED_NUMBER = 16;
    private static final int PEEKED_SINGLE_QUOTED = 8;
    private static final int PEEKED_SINGLE_QUOTED_NAME = 12;
    private static final int PEEKED_TRUE = 5;
    private static final int PEEKED_UNQUOTED = 10;
    private static final int PEEKED_UNQUOTED_NAME = 14;
    private final Reader in;
    private int[] pathIndices;
    private String[] pathNames;
    private long peekedLong;
    private int peekedNumberLength;
    private String peekedString;
    private int[] stack;
    private boolean lenient = false;
    private final char[] buffer = new char[1024];
    private int pos = 0;
    private int limit = 0;
    private int lineNumber = 0;
    private int lineStart = 0;
    int peeked = 0;
    private int stackSize = 0 + 1;

    static {
        JsonReaderInternalAccess.INSTANCE = new JsonReaderInternalAccess() { // from class: com.google.gson.stream.JsonReader.1
            @Override // com.google.gson.internal.JsonReaderInternalAccess
            public void promoteNameToValue(JsonReader jsonReader) throws IOException {
                if (jsonReader instanceof JsonTreeReader) {
                    ((JsonTreeReader) jsonReader).promoteNameToValue();
                    return;
                }
                int i6 = jsonReader.peeked;
                if (i6 == 0) {
                    i6 = jsonReader.doPeek();
                }
                if (i6 == 13) {
                    jsonReader.peeked = 9;
                } else if (i6 == 12) {
                    jsonReader.peeked = 8;
                } else if (i6 == 14) {
                    jsonReader.peeked = 10;
                } else {
                    throw new IllegalStateException("Expected a name but was " + jsonReader.peek() + jsonReader.locationString());
                }
            }
        };
    }

    public JsonReader(Reader reader) {
        int[] iArr = new int[32];
        this.stack = iArr;
        iArr[0] = 6;
        this.pathNames = new String[32];
        this.pathIndices = new int[32];
        if (reader != null) {
            this.in = reader;
            return;
        }
        throw new NullPointerException("in == null");
    }

    private void checkLenient() throws IOException {
        if (this.lenient) {
            return;
        }
        throw syntaxError("Use JsonReader.setLenient(true) to accept malformed JSON");
    }

    private void consumeNonExecutePrefix() throws IOException {
        nextNonWhitespace(true);
        int i6 = this.pos - 1;
        this.pos = i6;
        if (i6 + 5 > this.limit && !fillBuffer(5)) {
            return;
        }
        char[] cArr = this.buffer;
        if (cArr[i6] == ')' && cArr[i6 + 1] == ']' && cArr[i6 + 2] == '}' && cArr[i6 + 3] == '\'' && cArr[i6 + 4] == '\n') {
            this.pos += 5;
        }
    }

    private boolean fillBuffer(int i6) throws IOException {
        int i7;
        int i8;
        char[] cArr = this.buffer;
        int i9 = this.lineStart;
        int i10 = this.pos;
        this.lineStart = i9 - i10;
        int i11 = this.limit;
        if (i11 != i10) {
            int i12 = i11 - i10;
            this.limit = i12;
            System.arraycopy(cArr, i10, cArr, 0, i12);
        } else {
            this.limit = 0;
        }
        this.pos = 0;
        do {
            Reader reader = this.in;
            int i13 = this.limit;
            int read = reader.read(cArr, i13, cArr.length - i13);
            if (read == -1) {
                return false;
            }
            i7 = this.limit + read;
            this.limit = i7;
            if (this.lineNumber == 0 && (i8 = this.lineStart) == 0 && i7 > 0 && cArr[0] == 65279) {
                this.pos++;
                this.lineStart = i8 + 1;
                i6++;
                continue;
            }
        } while (i7 < i6);
        return true;
    }

    private boolean isLiteral(char c6) throws IOException {
        if (c6 != '\t' && c6 != '\n' && c6 != '\f' && c6 != '\r' && c6 != ' ') {
            if (c6 != '#') {
                if (c6 != ',') {
                    if (c6 != '/' && c6 != '=') {
                        if (c6 != '{' && c6 != '}' && c6 != ':') {
                            if (c6 != ';') {
                                switch (c6) {
                                    case '[':
                                    case ']':
                                        return false;
                                    case '\\':
                                        break;
                                    default:
                                        return true;
                                }
                            }
                        } else {
                            return false;
                        }
                    }
                } else {
                    return false;
                }
            }
            checkLenient();
            return false;
        }
        return false;
    }

    private int nextNonWhitespace(boolean z5) throws IOException {
        char[] cArr = this.buffer;
        int i6 = this.pos;
        int i7 = this.limit;
        while (true) {
            if (i6 == i7) {
                this.pos = i6;
                if (!fillBuffer(1)) {
                    if (!z5) {
                        return -1;
                    }
                    throw new EOFException("End of input" + locationString());
                }
                i6 = this.pos;
                i7 = this.limit;
            }
            int i8 = i6 + 1;
            char c6 = cArr[i6];
            if (c6 == '\n') {
                this.lineNumber++;
                this.lineStart = i8;
            } else if (c6 != ' ' && c6 != '\r' && c6 != '\t') {
                if (c6 == '/') {
                    this.pos = i8;
                    if (i8 == i7) {
                        this.pos = i8 - 1;
                        boolean fillBuffer = fillBuffer(2);
                        this.pos++;
                        if (!fillBuffer) {
                            return c6;
                        }
                    }
                    checkLenient();
                    int i9 = this.pos;
                    char c7 = cArr[i9];
                    if (c7 != '*') {
                        if (c7 != '/') {
                            return c6;
                        }
                        this.pos = i9 + 1;
                        skipToEndOfLine();
                        i6 = this.pos;
                        i7 = this.limit;
                    } else {
                        this.pos = i9 + 1;
                        if (skipTo("*/")) {
                            i6 = this.pos + 2;
                            i7 = this.limit;
                        } else {
                            throw syntaxError("Unterminated comment");
                        }
                    }
                } else if (c6 == '#') {
                    this.pos = i8;
                    checkLenient();
                    skipToEndOfLine();
                    i6 = this.pos;
                    i7 = this.limit;
                } else {
                    this.pos = i8;
                    return c6;
                }
            }
            i6 = i8;
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:25:0x005c, code lost:
        if (r1 != null) goto L34;
     */
    /* JADX WARN: Code restructure failed: missing block: B:26:0x005e, code lost:
        r1 = new java.lang.StringBuilder(java.lang.Math.max((r2 - r3) * 2, 16));
     */
    /* JADX WARN: Code restructure failed: missing block: B:27:0x006c, code lost:
        r1.append(r0, r3, r2 - r3);
        r9.pos = r2;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private String nextQuotedValue(char c6) throws IOException {
        char[] cArr = this.buffer;
        StringBuilder sb = null;
        do {
            int i6 = this.pos;
            int i7 = this.limit;
            while (true) {
                int i8 = i7;
                int i9 = i6;
                while (i6 < i8) {
                    int i10 = i6 + 1;
                    char c7 = cArr[i6];
                    if (c7 == c6) {
                        this.pos = i10;
                        int i11 = (i10 - i9) - 1;
                        if (sb == null) {
                            return new String(cArr, i9, i11);
                        }
                        sb.append(cArr, i9, i11);
                        return sb.toString();
                    } else if (c7 == '\\') {
                        this.pos = i10;
                        int i12 = (i10 - i9) - 1;
                        if (sb == null) {
                            sb = new StringBuilder(Math.max((i12 + 1) * 2, 16));
                        }
                        sb.append(cArr, i9, i12);
                        sb.append(readEscapeCharacter());
                        i6 = this.pos;
                        i7 = this.limit;
                    } else {
                        if (c7 == '\n') {
                            this.lineNumber++;
                            this.lineStart = i10;
                        }
                        i6 = i10;
                    }
                }
                break;
            }
        } while (fillBuffer(1));
        throw syntaxError("Unterminated string");
    }

    /* JADX WARN: Code restructure failed: missing block: B:34:0x004a, code lost:
        checkLenient();
     */
    /* JADX WARN: Removed duplicated region for block: B:46:0x0080  */
    /* JADX WARN: Removed duplicated region for block: B:47:0x008a  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private String nextUnquotedValue() throws IOException {
        String sb;
        StringBuilder sb2 = null;
        int i6 = 0;
        do {
            int i7 = 0;
            while (true) {
                int i8 = this.pos;
                if (i8 + i7 < this.limit) {
                    char c6 = this.buffer[i8 + i7];
                    if (c6 != '\t' && c6 != '\n' && c6 != '\f' && c6 != '\r' && c6 != ' ') {
                        if (c6 != '#') {
                            if (c6 != ',') {
                                if (c6 != '/' && c6 != '=') {
                                    if (c6 != '{' && c6 != '}' && c6 != ':') {
                                        if (c6 != ';') {
                                            switch (c6) {
                                                case '[':
                                                case ']':
                                                    break;
                                                case '\\':
                                                    break;
                                                default:
                                                    i7++;
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                } else if (i7 < this.buffer.length) {
                    if (fillBuffer(i7 + 1)) {
                    }
                } else {
                    if (sb2 == null) {
                        sb2 = new StringBuilder(Math.max(i7, 16));
                    }
                    sb2.append(this.buffer, this.pos, i7);
                    this.pos += i7;
                }
            }
            i6 = i7;
            if (sb2 != null) {
                sb = new String(this.buffer, this.pos, i6);
            } else {
                sb2.append(this.buffer, this.pos, i6);
                sb = sb2.toString();
            }
            this.pos += i6;
            return sb;
        } while (fillBuffer(1));
        if (sb2 != null) {
        }
        this.pos += i6;
        return sb;
    }

    private int peekKeyword() throws IOException {
        String str;
        String str2;
        int i6;
        char c6 = this.buffer[this.pos];
        if (c6 != 't' && c6 != 'T') {
            if (c6 != 'f' && c6 != 'F') {
                if (c6 != 'n' && c6 != 'N') {
                    return 0;
                }
                str = "null";
                str2 = "NULL";
                i6 = 7;
            } else {
                str = "false";
                str2 = "FALSE";
                i6 = 6;
            }
        } else {
            str = "true";
            str2 = "TRUE";
            i6 = 5;
        }
        int length = str.length();
        for (int i7 = 1; i7 < length; i7++) {
            if (this.pos + i7 >= this.limit && !fillBuffer(i7 + 1)) {
                return 0;
            }
            char c7 = this.buffer[this.pos + i7];
            if (c7 != str.charAt(i7) && c7 != str2.charAt(i7)) {
                return 0;
            }
        }
        if ((this.pos + length < this.limit || fillBuffer(length + 1)) && isLiteral(this.buffer[this.pos + length])) {
            return 0;
        }
        this.pos += length;
        this.peeked = i6;
        return i6;
    }

    /* JADX WARN: Code restructure failed: missing block: B:56:0x0097, code lost:
        if (isLiteral(r14) != false) goto L77;
     */
    /* JADX WARN: Code restructure failed: missing block: B:57:0x0099, code lost:
        if (r9 != 2) goto L23;
     */
    /* JADX WARN: Code restructure failed: missing block: B:58:0x009b, code lost:
        if (r10 == false) goto L23;
     */
    /* JADX WARN: Code restructure failed: missing block: B:60:0x00a1, code lost:
        if (r11 != Long.MIN_VALUE) goto L15;
     */
    /* JADX WARN: Code restructure failed: missing block: B:61:0x00a3, code lost:
        if (r13 == false) goto L23;
     */
    /* JADX WARN: Code restructure failed: missing block: B:63:0x00a9, code lost:
        if (r11 != 0) goto L18;
     */
    /* JADX WARN: Code restructure failed: missing block: B:64:0x00ab, code lost:
        if (r13 != false) goto L23;
     */
    /* JADX WARN: Code restructure failed: missing block: B:65:0x00ad, code lost:
        if (r13 == false) goto L19;
     */
    /* JADX WARN: Code restructure failed: missing block: B:67:0x00b0, code lost:
        r11 = -r11;
     */
    /* JADX WARN: Code restructure failed: missing block: B:68:0x00b1, code lost:
        r18.peekedLong = r11;
        r18.pos += r8;
        r18.peeked = 15;
     */
    /* JADX WARN: Code restructure failed: missing block: B:69:0x00bc, code lost:
        return 15;
     */
    /* JADX WARN: Code restructure failed: missing block: B:70:0x00bd, code lost:
        if (r9 == 2) goto L29;
     */
    /* JADX WARN: Code restructure failed: missing block: B:72:0x00c0, code lost:
        if (r9 == 4) goto L29;
     */
    /* JADX WARN: Code restructure failed: missing block: B:74:0x00c3, code lost:
        if (r9 != 7) goto L28;
     */
    /* JADX WARN: Code restructure failed: missing block: B:76:0x00c6, code lost:
        return 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:78:0x00c8, code lost:
        r18.peekedNumberLength = r8;
        r18.peeked = 16;
     */
    /* JADX WARN: Code restructure failed: missing block: B:79:0x00ce, code lost:
        return 16;
     */
    /* JADX WARN: Code restructure failed: missing block: B:80:0x00cf, code lost:
        return 0;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private int peekNumber() throws IOException {
        boolean z5;
        char[] cArr = this.buffer;
        int i6 = this.pos;
        int i7 = this.limit;
        int i8 = 0;
        int i9 = 0;
        char c6 = 0;
        boolean z6 = true;
        long j6 = 0;
        boolean z7 = false;
        while (true) {
            if (i6 + i9 == i7) {
                if (i9 == cArr.length) {
                    return i8;
                }
                if (!fillBuffer(i9 + 1)) {
                    break;
                }
                i6 = this.pos;
                i7 = this.limit;
            }
            char c7 = cArr[i6 + i9];
            if (c7 != '+') {
                if (c7 != 'E' && c7 != 'e') {
                    if (c7 != '-') {
                        if (c7 != '.') {
                            if (c7 < '0' || c7 > '9') {
                                break;
                            } else if (c6 != 1 && c6 != 0) {
                                if (c6 == 2) {
                                    if (j6 == 0) {
                                        return 0;
                                    }
                                    long j7 = (10 * j6) - (c7 - '0');
                                    if (j6 <= MIN_INCOMPLETE_INTEGER && (j6 != MIN_INCOMPLETE_INTEGER || j7 >= j6)) {
                                        z5 = false;
                                    } else {
                                        z5 = true;
                                    }
                                    z6 &= z5;
                                    j6 = j7;
                                } else if (c6 == 3) {
                                    i8 = 0;
                                    c6 = 4;
                                } else if (c6 == 5 || c6 == 6) {
                                    i8 = 0;
                                    c6 = 7;
                                }
                                i8 = 0;
                            } else {
                                j6 = -(c7 - '0');
                                i8 = 0;
                                c6 = 2;
                            }
                        } else {
                            i8 = 0;
                            if (c6 != 2) {
                                return 0;
                            }
                            c6 = 3;
                        }
                    } else {
                        i8 = 0;
                        if (c6 == 0) {
                            c6 = 1;
                            z7 = true;
                        } else if (c6 != 5) {
                            return 0;
                        }
                    }
                } else {
                    i8 = 0;
                    if (c6 != 2 && c6 != 4) {
                        return 0;
                    }
                    c6 = 5;
                }
                i9++;
            } else {
                i8 = 0;
                if (c6 != 5) {
                    return 0;
                }
            }
            c6 = 6;
            i9++;
        }
    }

    private void push(int i6) {
        int i7 = this.stackSize;
        int[] iArr = this.stack;
        if (i7 == iArr.length) {
            int i8 = i7 * 2;
            this.stack = Arrays.copyOf(iArr, i8);
            this.pathIndices = Arrays.copyOf(this.pathIndices, i8);
            this.pathNames = (String[]) Arrays.copyOf(this.pathNames, i8);
        }
        int[] iArr2 = this.stack;
        int i9 = this.stackSize;
        this.stackSize = i9 + 1;
        iArr2[i9] = i6;
    }

    private char readEscapeCharacter() throws IOException {
        int i6;
        int i7;
        if (this.pos == this.limit && !fillBuffer(1)) {
            throw syntaxError("Unterminated escape sequence");
        }
        char[] cArr = this.buffer;
        int i8 = this.pos;
        int i9 = i8 + 1;
        this.pos = i9;
        char c6 = cArr[i8];
        if (c6 != '\n') {
            if (c6 != '\"' && c6 != '\'' && c6 != '/' && c6 != '\\') {
                if (c6 != 'b') {
                    if (c6 != 'f') {
                        if (c6 == 'n') {
                            return '\n';
                        }
                        if (c6 != 'r') {
                            if (c6 != 't') {
                                if (c6 == 'u') {
                                    if (i9 + 4 > this.limit && !fillBuffer(4)) {
                                        throw syntaxError("Unterminated escape sequence");
                                    }
                                    int i10 = this.pos;
                                    int i11 = i10 + 4;
                                    char c7 = 0;
                                    while (i10 < i11) {
                                        char c8 = this.buffer[i10];
                                        char c9 = (char) (c7 << 4);
                                        if (c8 >= '0' && c8 <= '9') {
                                            i7 = c8 - '0';
                                        } else {
                                            if (c8 >= 'a' && c8 <= 'f') {
                                                i6 = c8 - 'a';
                                            } else if (c8 >= 'A' && c8 <= 'F') {
                                                i6 = c8 - 'A';
                                            } else {
                                                throw new NumberFormatException("\\u" + new String(this.buffer, this.pos, 4));
                                            }
                                            i7 = i6 + 10;
                                        }
                                        c7 = (char) (c9 + i7);
                                        i10++;
                                    }
                                    this.pos += 4;
                                    return c7;
                                }
                                throw syntaxError("Invalid escape sequence");
                            }
                            return '\t';
                        }
                        return '\r';
                    }
                    return '\f';
                }
                return '\b';
            }
        } else {
            this.lineNumber++;
            this.lineStart = i9;
        }
        return c6;
    }

    private void skipQuotedValue(char c6) throws IOException {
        char[] cArr = this.buffer;
        do {
            int i6 = this.pos;
            int i7 = this.limit;
            while (i6 < i7) {
                int i8 = i6 + 1;
                char c7 = cArr[i6];
                if (c7 == c6) {
                    this.pos = i8;
                    return;
                } else if (c7 == '\\') {
                    this.pos = i8;
                    readEscapeCharacter();
                    i6 = this.pos;
                    i7 = this.limit;
                } else {
                    if (c7 == '\n') {
                        this.lineNumber++;
                        this.lineStart = i8;
                    }
                    i6 = i8;
                }
            }
            this.pos = i6;
        } while (fillBuffer(1));
        throw syntaxError("Unterminated string");
    }

    private boolean skipTo(String str) throws IOException {
        int length = str.length();
        while (true) {
            if (this.pos + length > this.limit && !fillBuffer(length)) {
                return false;
            }
            char[] cArr = this.buffer;
            int i6 = this.pos;
            if (cArr[i6] == '\n') {
                this.lineNumber++;
                this.lineStart = i6 + 1;
            } else {
                for (int i7 = 0; i7 < length; i7++) {
                    if (this.buffer[this.pos + i7] != str.charAt(i7)) {
                        break;
                    }
                }
                return true;
            }
            this.pos++;
        }
    }

    private void skipToEndOfLine() throws IOException {
        char c6;
        do {
            if (this.pos < this.limit || fillBuffer(1)) {
                char[] cArr = this.buffer;
                int i6 = this.pos;
                int i7 = i6 + 1;
                this.pos = i7;
                c6 = cArr[i6];
                if (c6 == '\n') {
                    this.lineNumber++;
                    this.lineStart = i7;
                    return;
                }
            } else {
                return;
            }
        } while (c6 != '\r');
    }

    /* JADX WARN: Code restructure failed: missing block: B:33:0x0048, code lost:
        checkLenient();
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private void skipUnquotedValue() throws IOException {
        do {
            int i6 = 0;
            while (true) {
                int i7 = this.pos;
                if (i7 + i6 < this.limit) {
                    char c6 = this.buffer[i7 + i6];
                    if (c6 != '\t' && c6 != '\n' && c6 != '\f' && c6 != '\r' && c6 != ' ') {
                        if (c6 != '#') {
                            if (c6 != ',') {
                                if (c6 != '/' && c6 != '=') {
                                    if (c6 != '{' && c6 != '}' && c6 != ':') {
                                        if (c6 != ';') {
                                            switch (c6) {
                                                case '[':
                                                case ']':
                                                    break;
                                                case '\\':
                                                    break;
                                                default:
                                                    i6++;
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                } else {
                    this.pos = i7 + i6;
                }
            }
            this.pos += i6;
            return;
        } while (fillBuffer(1));
    }

    private IOException syntaxError(String str) throws IOException {
        throw new MalformedJsonException(str + locationString());
    }

    public void beginArray() throws IOException {
        int i6 = this.peeked;
        if (i6 == 0) {
            i6 = doPeek();
        }
        if (i6 == 3) {
            push(1);
            this.pathIndices[this.stackSize - 1] = 0;
            this.peeked = 0;
            return;
        }
        throw new IllegalStateException("Expected BEGIN_ARRAY but was " + peek() + locationString());
    }

    public void beginObject() throws IOException {
        int i6 = this.peeked;
        if (i6 == 0) {
            i6 = doPeek();
        }
        if (i6 == 1) {
            push(3);
            this.peeked = 0;
            return;
        }
        throw new IllegalStateException("Expected BEGIN_OBJECT but was " + peek() + locationString());
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() throws IOException {
        this.peeked = 0;
        this.stack[0] = 8;
        this.stackSize = 1;
        this.in.close();
    }

    int doPeek() throws IOException {
        int nextNonWhitespace;
        int[] iArr = this.stack;
        int i6 = this.stackSize;
        int i7 = iArr[i6 - 1];
        if (i7 == 1) {
            iArr[i6 - 1] = 2;
        } else if (i7 == 2) {
            int nextNonWhitespace2 = nextNonWhitespace(true);
            if (nextNonWhitespace2 != 44) {
                if (nextNonWhitespace2 != 59) {
                    if (nextNonWhitespace2 == 93) {
                        this.peeked = 4;
                        return 4;
                    }
                    throw syntaxError("Unterminated array");
                }
                checkLenient();
            }
        } else if (i7 != 3 && i7 != 5) {
            if (i7 == 4) {
                iArr[i6 - 1] = 5;
                int nextNonWhitespace3 = nextNonWhitespace(true);
                if (nextNonWhitespace3 != 58) {
                    if (nextNonWhitespace3 == 61) {
                        checkLenient();
                        if (this.pos < this.limit || fillBuffer(1)) {
                            char[] cArr = this.buffer;
                            int i8 = this.pos;
                            if (cArr[i8] == '>') {
                                this.pos = i8 + 1;
                            }
                        }
                    } else {
                        throw syntaxError("Expected ':'");
                    }
                }
            } else if (i7 == 6) {
                if (this.lenient) {
                    consumeNonExecutePrefix();
                }
                this.stack[this.stackSize - 1] = 7;
            } else if (i7 == 7) {
                if (nextNonWhitespace(false) == -1) {
                    this.peeked = 17;
                    return 17;
                }
                checkLenient();
                this.pos--;
            } else if (i7 == 8) {
                throw new IllegalStateException("JsonReader is closed");
            }
        } else {
            iArr[i6 - 1] = 4;
            if (i7 == 5 && (nextNonWhitespace = nextNonWhitespace(true)) != 44) {
                if (nextNonWhitespace != 59) {
                    if (nextNonWhitespace == 125) {
                        this.peeked = 2;
                        return 2;
                    }
                    throw syntaxError("Unterminated object");
                }
                checkLenient();
            }
            int nextNonWhitespace4 = nextNonWhitespace(true);
            if (nextNonWhitespace4 != 34) {
                if (nextNonWhitespace4 != 39) {
                    if (nextNonWhitespace4 != 125) {
                        checkLenient();
                        this.pos--;
                        if (isLiteral((char) nextNonWhitespace4)) {
                            this.peeked = 14;
                            return 14;
                        }
                        throw syntaxError("Expected name");
                    } else if (i7 != 5) {
                        this.peeked = 2;
                        return 2;
                    } else {
                        throw syntaxError("Expected name");
                    }
                }
                checkLenient();
                this.peeked = 12;
                return 12;
            }
            this.peeked = 13;
            return 13;
        }
        int nextNonWhitespace5 = nextNonWhitespace(true);
        if (nextNonWhitespace5 != 34) {
            if (nextNonWhitespace5 != 39) {
                if (nextNonWhitespace5 != 44 && nextNonWhitespace5 != 59) {
                    if (nextNonWhitespace5 != 91) {
                        if (nextNonWhitespace5 != 93) {
                            if (nextNonWhitespace5 != 123) {
                                this.pos--;
                                int peekKeyword = peekKeyword();
                                if (peekKeyword != 0) {
                                    return peekKeyword;
                                }
                                int peekNumber = peekNumber();
                                if (peekNumber != 0) {
                                    return peekNumber;
                                }
                                if (isLiteral(this.buffer[this.pos])) {
                                    checkLenient();
                                    this.peeked = 10;
                                    return 10;
                                }
                                throw syntaxError("Expected value");
                            }
                            this.peeked = 1;
                            return 1;
                        } else if (i7 == 1) {
                            this.peeked = 4;
                            return 4;
                        }
                    } else {
                        this.peeked = 3;
                        return 3;
                    }
                }
                if (i7 != 1 && i7 != 2) {
                    throw syntaxError("Unexpected value");
                }
                checkLenient();
                this.pos--;
                this.peeked = 7;
                return 7;
            }
            checkLenient();
            this.peeked = 8;
            return 8;
        }
        this.peeked = 9;
        return 9;
    }

    public void endArray() throws IOException {
        int i6 = this.peeked;
        if (i6 == 0) {
            i6 = doPeek();
        }
        if (i6 == 4) {
            int i7 = this.stackSize - 1;
            this.stackSize = i7;
            int[] iArr = this.pathIndices;
            int i8 = i7 - 1;
            iArr[i8] = iArr[i8] + 1;
            this.peeked = 0;
            return;
        }
        throw new IllegalStateException("Expected END_ARRAY but was " + peek() + locationString());
    }

    public void endObject() throws IOException {
        int i6 = this.peeked;
        if (i6 == 0) {
            i6 = doPeek();
        }
        if (i6 == 2) {
            int i7 = this.stackSize - 1;
            this.stackSize = i7;
            this.pathNames[i7] = null;
            int[] iArr = this.pathIndices;
            int i8 = i7 - 1;
            iArr[i8] = iArr[i8] + 1;
            this.peeked = 0;
            return;
        }
        throw new IllegalStateException("Expected END_OBJECT but was " + peek() + locationString());
    }

    public String getPath() {
        StringBuilder sb = new StringBuilder();
        sb.append('$');
        int i6 = this.stackSize;
        for (int i7 = 0; i7 < i6; i7++) {
            int i8 = this.stack[i7];
            if (i8 != 1 && i8 != 2) {
                if (i8 == 3 || i8 == 4 || i8 == 5) {
                    sb.append('.');
                    String str = this.pathNames[i7];
                    if (str != null) {
                        sb.append(str);
                    }
                }
            } else {
                sb.append('[');
                sb.append(this.pathIndices[i7]);
                sb.append(']');
            }
        }
        return sb.toString();
    }

    public boolean hasNext() throws IOException {
        int i6 = this.peeked;
        if (i6 == 0) {
            i6 = doPeek();
        }
        if (i6 != 2 && i6 != 4) {
            return true;
        }
        return false;
    }

    public final boolean isLenient() {
        return this.lenient;
    }

    String locationString() {
        return " at line " + (this.lineNumber + 1) + " column " + ((this.pos - this.lineStart) + 1) + " path " + getPath();
    }

    public boolean nextBoolean() throws IOException {
        int i6 = this.peeked;
        if (i6 == 0) {
            i6 = doPeek();
        }
        if (i6 == 5) {
            this.peeked = 0;
            int[] iArr = this.pathIndices;
            int i7 = this.stackSize - 1;
            iArr[i7] = iArr[i7] + 1;
            return true;
        } else if (i6 == 6) {
            this.peeked = 0;
            int[] iArr2 = this.pathIndices;
            int i8 = this.stackSize - 1;
            iArr2[i8] = iArr2[i8] + 1;
            return false;
        } else {
            throw new IllegalStateException("Expected a boolean but was " + peek() + locationString());
        }
    }

    public double nextDouble() throws IOException {
        char c6;
        int i6 = this.peeked;
        if (i6 == 0) {
            i6 = doPeek();
        }
        if (i6 == 15) {
            this.peeked = 0;
            int[] iArr = this.pathIndices;
            int i7 = this.stackSize - 1;
            iArr[i7] = iArr[i7] + 1;
            return this.peekedLong;
        }
        if (i6 == 16) {
            this.peekedString = new String(this.buffer, this.pos, this.peekedNumberLength);
            this.pos += this.peekedNumberLength;
        } else if (i6 != 8 && i6 != 9) {
            if (i6 == 10) {
                this.peekedString = nextUnquotedValue();
            } else if (i6 != 11) {
                throw new IllegalStateException("Expected a double but was " + peek() + locationString());
            }
        } else {
            if (i6 == 8) {
                c6 = '\'';
            } else {
                c6 = '\"';
            }
            this.peekedString = nextQuotedValue(c6);
        }
        this.peeked = 11;
        double parseDouble = Double.parseDouble(this.peekedString);
        if (!this.lenient && (Double.isNaN(parseDouble) || Double.isInfinite(parseDouble))) {
            throw new MalformedJsonException("JSON forbids NaN and infinities: " + parseDouble + locationString());
        }
        this.peekedString = null;
        this.peeked = 0;
        int[] iArr2 = this.pathIndices;
        int i8 = this.stackSize - 1;
        iArr2[i8] = iArr2[i8] + 1;
        return parseDouble;
    }

    public int nextInt() throws IOException {
        char c6;
        int i6 = this.peeked;
        if (i6 == 0) {
            i6 = doPeek();
        }
        if (i6 == 15) {
            long j6 = this.peekedLong;
            int i7 = (int) j6;
            if (j6 == i7) {
                this.peeked = 0;
                int[] iArr = this.pathIndices;
                int i8 = this.stackSize - 1;
                iArr[i8] = iArr[i8] + 1;
                return i7;
            }
            throw new NumberFormatException("Expected an int but was " + this.peekedLong + locationString());
        }
        if (i6 == 16) {
            this.peekedString = new String(this.buffer, this.pos, this.peekedNumberLength);
            this.pos += this.peekedNumberLength;
        } else if (i6 != 8 && i6 != 9 && i6 != 10) {
            throw new IllegalStateException("Expected an int but was " + peek() + locationString());
        } else {
            if (i6 == 10) {
                this.peekedString = nextUnquotedValue();
            } else {
                if (i6 == 8) {
                    c6 = '\'';
                } else {
                    c6 = '\"';
                }
                this.peekedString = nextQuotedValue(c6);
            }
            try {
                int parseInt = Integer.parseInt(this.peekedString);
                this.peeked = 0;
                int[] iArr2 = this.pathIndices;
                int i9 = this.stackSize - 1;
                iArr2[i9] = iArr2[i9] + 1;
                return parseInt;
            } catch (NumberFormatException unused) {
            }
        }
        this.peeked = 11;
        double parseDouble = Double.parseDouble(this.peekedString);
        int i10 = (int) parseDouble;
        if (i10 == parseDouble) {
            this.peekedString = null;
            this.peeked = 0;
            int[] iArr3 = this.pathIndices;
            int i11 = this.stackSize - 1;
            iArr3[i11] = iArr3[i11] + 1;
            return i10;
        }
        throw new NumberFormatException("Expected an int but was " + this.peekedString + locationString());
    }

    public long nextLong() throws IOException {
        char c6;
        int i6 = this.peeked;
        if (i6 == 0) {
            i6 = doPeek();
        }
        if (i6 == 15) {
            this.peeked = 0;
            int[] iArr = this.pathIndices;
            int i7 = this.stackSize - 1;
            iArr[i7] = iArr[i7] + 1;
            return this.peekedLong;
        }
        if (i6 == 16) {
            this.peekedString = new String(this.buffer, this.pos, this.peekedNumberLength);
            this.pos += this.peekedNumberLength;
        } else if (i6 != 8 && i6 != 9 && i6 != 10) {
            throw new IllegalStateException("Expected a long but was " + peek() + locationString());
        } else {
            if (i6 == 10) {
                this.peekedString = nextUnquotedValue();
            } else {
                if (i6 == 8) {
                    c6 = '\'';
                } else {
                    c6 = '\"';
                }
                this.peekedString = nextQuotedValue(c6);
            }
            try {
                long parseLong = Long.parseLong(this.peekedString);
                this.peeked = 0;
                int[] iArr2 = this.pathIndices;
                int i8 = this.stackSize - 1;
                iArr2[i8] = iArr2[i8] + 1;
                return parseLong;
            } catch (NumberFormatException unused) {
            }
        }
        this.peeked = 11;
        double parseDouble = Double.parseDouble(this.peekedString);
        long j6 = (long) parseDouble;
        if (j6 == parseDouble) {
            this.peekedString = null;
            this.peeked = 0;
            int[] iArr3 = this.pathIndices;
            int i9 = this.stackSize - 1;
            iArr3[i9] = iArr3[i9] + 1;
            return j6;
        }
        throw new NumberFormatException("Expected a long but was " + this.peekedString + locationString());
    }

    public String nextName() throws IOException {
        String nextQuotedValue;
        int i6 = this.peeked;
        if (i6 == 0) {
            i6 = doPeek();
        }
        if (i6 == 14) {
            nextQuotedValue = nextUnquotedValue();
        } else if (i6 == 12) {
            nextQuotedValue = nextQuotedValue('\'');
        } else if (i6 == 13) {
            nextQuotedValue = nextQuotedValue('\"');
        } else {
            throw new IllegalStateException("Expected a name but was " + peek() + locationString());
        }
        this.peeked = 0;
        this.pathNames[this.stackSize - 1] = nextQuotedValue;
        return nextQuotedValue;
    }

    public void nextNull() throws IOException {
        int i6 = this.peeked;
        if (i6 == 0) {
            i6 = doPeek();
        }
        if (i6 == 7) {
            this.peeked = 0;
            int[] iArr = this.pathIndices;
            int i7 = this.stackSize - 1;
            iArr[i7] = iArr[i7] + 1;
            return;
        }
        throw new IllegalStateException("Expected null but was " + peek() + locationString());
    }

    public String nextString() throws IOException {
        String str;
        int i6 = this.peeked;
        if (i6 == 0) {
            i6 = doPeek();
        }
        if (i6 == 10) {
            str = nextUnquotedValue();
        } else if (i6 == 8) {
            str = nextQuotedValue('\'');
        } else if (i6 == 9) {
            str = nextQuotedValue('\"');
        } else if (i6 == 11) {
            str = this.peekedString;
            this.peekedString = null;
        } else if (i6 == 15) {
            str = Long.toString(this.peekedLong);
        } else if (i6 == 16) {
            str = new String(this.buffer, this.pos, this.peekedNumberLength);
            this.pos += this.peekedNumberLength;
        } else {
            throw new IllegalStateException("Expected a string but was " + peek() + locationString());
        }
        this.peeked = 0;
        int[] iArr = this.pathIndices;
        int i7 = this.stackSize - 1;
        iArr[i7] = iArr[i7] + 1;
        return str;
    }

    public JsonToken peek() throws IOException {
        int i6 = this.peeked;
        if (i6 == 0) {
            i6 = doPeek();
        }
        switch (i6) {
            case 1:
                return JsonToken.BEGIN_OBJECT;
            case 2:
                return JsonToken.END_OBJECT;
            case 3:
                return JsonToken.BEGIN_ARRAY;
            case 4:
                return JsonToken.END_ARRAY;
            case 5:
            case 6:
                return JsonToken.BOOLEAN;
            case 7:
                return JsonToken.NULL;
            case 8:
            case 9:
            case 10:
            case 11:
                return JsonToken.STRING;
            case 12:
            case 13:
            case 14:
                return JsonToken.NAME;
            case 15:
            case 16:
                return JsonToken.NUMBER;
            case 17:
                return JsonToken.END_DOCUMENT;
            default:
                throw new AssertionError();
        }
    }

    public final void setLenient(boolean z5) {
        this.lenient = z5;
    }

    public void skipValue() throws IOException {
        int i6 = 0;
        do {
            int i7 = this.peeked;
            if (i7 == 0) {
                i7 = doPeek();
            }
            if (i7 == 3) {
                push(1);
            } else if (i7 == 1) {
                push(3);
            } else {
                if (i7 == 4) {
                    this.stackSize--;
                } else if (i7 == 2) {
                    this.stackSize--;
                } else {
                    if (i7 != 14 && i7 != 10) {
                        if (i7 != 8 && i7 != 12) {
                            if (i7 != 9 && i7 != 13) {
                                if (i7 == 16) {
                                    this.pos += this.peekedNumberLength;
                                }
                            } else {
                                skipQuotedValue('\"');
                            }
                        } else {
                            skipQuotedValue('\'');
                        }
                    } else {
                        skipUnquotedValue();
                    }
                    this.peeked = 0;
                }
                i6--;
                this.peeked = 0;
            }
            i6++;
            this.peeked = 0;
        } while (i6 != 0);
        int[] iArr = this.pathIndices;
        int i8 = this.stackSize;
        int i9 = i8 - 1;
        iArr[i9] = iArr[i9] + 1;
        this.pathNames[i8 - 1] = "null";
    }

    public String toString() {
        return getClass().getSimpleName() + locationString();
    }
}
