package s3;

import java.io.IOException;
import java.security.cert.CertificateParsingException;
import java.security.cert.X509Certificate;
import java.util.Arrays;
import java.util.Collection;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Locale;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.regex.Pattern;
import javax.net.ssl.SSLException;
import javax.net.ssl.SSLSession;
import javax.net.ssl.SSLSocket;
import org.apache.http.conn.ssl.X509HostnameVerifier;
/* compiled from: AbstractVerifier.java */
/* loaded from: classes.dex */
public abstract class a implements X509HostnameVerifier {

    /* renamed from: ʻ  reason: contains not printable characters */
    private static final Pattern f12362 = Pattern.compile("^(25[0-5]|2[0-4]\\d|[0-1]?\\d?\\d)(\\.(25[0-5]|2[0-4]\\d|[0-1]?\\d?\\d)){3}$");

    /* renamed from: ʼ  reason: contains not printable characters */
    private static final String[] f12363;

    static {
        String[] strArr = {"ac", "co", "com", "ed", "edu", "go", "gouv", "gov", "info", "lg", "ne", "net", "or", "org"};
        f12363 = strArr;
        Arrays.sort(strArr);
    }

    /* renamed from: ʻ  reason: contains not printable characters */
    public static boolean m13214(String str) {
        int length = str.length();
        if (length < 7 || length > 9) {
            return true;
        }
        int i6 = length - 3;
        if (str.charAt(i6) != '.') {
            return true;
        }
        if (Arrays.binarySearch(f12363, str.substring(2, i6)) < 0) {
            return true;
        }
        return false;
    }

    /* renamed from: ʼ  reason: contains not printable characters */
    public static int m13215(String str) {
        int i6 = 0;
        for (int i7 = 0; i7 < str.length(); i7++) {
            if (str.charAt(i7) == '.') {
                i6++;
            }
        }
        return i6;
    }

    /* renamed from: ʽ  reason: contains not printable characters */
    public static String[] m13216(X509Certificate x509Certificate) {
        List<String> m13227 = new b(x509Certificate.getSubjectX500Principal()).m13227("cn");
        if (!m13227.isEmpty()) {
            String[] strArr = new String[m13227.size()];
            m13227.toArray(strArr);
            return strArr;
        }
        return null;
    }

    /* renamed from: ʾ  reason: contains not printable characters */
    public static String[] m13217(X509Certificate x509Certificate) {
        Collection<List<?>> collection;
        LinkedList linkedList = new LinkedList();
        try {
            collection = x509Certificate.getSubjectAlternativeNames();
        } catch (CertificateParsingException e6) {
            Logger.getLogger(a.class.getName()).log(Level.FINE, "Error parsing certificate.", (Throwable) e6);
            collection = null;
        }
        if (collection != null) {
            for (List<?> list : collection) {
                if (((Integer) list.get(0)).intValue() == 2) {
                    linkedList.add((String) list.get(1));
                }
            }
        }
        if (linkedList.isEmpty()) {
            return null;
        }
        String[] strArr = new String[linkedList.size()];
        linkedList.toArray(strArr);
        return strArr;
    }

    /* renamed from: ʿ  reason: contains not printable characters */
    private static boolean m13218(String str) {
        return f12362.matcher(str).matches();
    }

    @Override // org.apache.http.conn.ssl.X509HostnameVerifier
    public final void verify(String str, SSLSocket sSLSocket) throws IOException {
        if (str != null) {
            verify(str, (X509Certificate) sSLSocket.getSession().getPeerCertificates()[0]);
            return;
        }
        throw new NullPointerException("host to verify is null");
    }

    /* renamed from: ˆ  reason: contains not printable characters */
    public final void m13219(String str, String[] strArr, String[] strArr2, boolean z5) throws SSLException {
        boolean z6;
        String str2;
        LinkedList linkedList = new LinkedList();
        if (strArr != null && strArr.length > 0 && (str2 = strArr[0]) != null) {
            linkedList.add(str2);
        }
        if (strArr2 != null) {
            for (String str3 : strArr2) {
                if (str3 != null) {
                    linkedList.add(str3);
                }
            }
        }
        if (!linkedList.isEmpty()) {
            StringBuffer stringBuffer = new StringBuffer();
            String lowerCase = str.trim().toLowerCase(Locale.ENGLISH);
            Iterator it = linkedList.iterator();
            boolean z7 = false;
            while (it.hasNext()) {
                String lowerCase2 = ((String) it.next()).toLowerCase(Locale.ENGLISH);
                stringBuffer.append(" <");
                stringBuffer.append(lowerCase2);
                stringBuffer.append('>');
                if (it.hasNext()) {
                    stringBuffer.append(" OR");
                }
                boolean z8 = true;
                if (lowerCase2.startsWith("*.") && lowerCase2.indexOf(46, 2) != -1 && m13214(lowerCase2) && !m13218(str)) {
                    z6 = true;
                } else {
                    z6 = false;
                }
                if (z6) {
                    boolean endsWith = lowerCase.endsWith(lowerCase2.substring(1));
                    if (endsWith && z5) {
                        if (m13215(lowerCase) != m13215(lowerCase2)) {
                            z8 = false;
                        }
                        z7 = z8;
                        continue;
                    } else {
                        z7 = endsWith;
                        continue;
                    }
                } else {
                    z7 = lowerCase.equals(lowerCase2);
                    continue;
                }
                if (z7) {
                    break;
                }
            }
            if (z7) {
                return;
            }
            throw new SSLException("hostname in certificate didn't match: <" + str + "> !=" + ((Object) stringBuffer));
        }
        throw new SSLException("Certificate for <" + str + "> doesn't contain CN or DNS subjectAlt");
    }

    @Override // org.apache.http.conn.ssl.X509HostnameVerifier, javax.net.ssl.HostnameVerifier
    public final boolean verify(String str, SSLSession sSLSession) {
        try {
            verify(str, (X509Certificate) sSLSession.getPeerCertificates()[0]);
            return true;
        } catch (SSLException unused) {
            return false;
        }
    }

    @Override // org.apache.http.conn.ssl.X509HostnameVerifier
    public final void verify(String str, X509Certificate x509Certificate) throws SSLException {
        verify(str, m13216(x509Certificate), m13217(x509Certificate));
    }
}
